@@ -60,7 +60,7 @@ contact_list_base_init (gpointer klass)
 			      NULL, NULL,
 			      g_cclosure_marshal_VOID__OBJECT,
 			      G_TYPE_NONE,
-			      1, GOSSIP_TYPE_CONTACT);
+			      1, EMPATHY_TYPE_CONTACT);
 
 		g_signal_new ("contact-removed",
 			      G_TYPE_FROM_CLASS (klass),
@@ -69,7 +69,7 @@ contact_list_base_init (gpointer klass)
 			      NULL, NULL,
 			      g_cclosure_marshal_VOID__OBJECT,
 			      G_TYPE_NONE,
-			      1, GOSSIP_TYPE_CONTACT);
+			      1, EMPATHY_TYPE_CONTACT);
 
 		g_signal_new ("local-pending",
 			      G_TYPE_FROM_CLASS (klass),
@@ -78,19 +78,19 @@ contact_list_base_init (gpointer klass)
 			      NULL, NULL,
 			      empathy_marshal_VOID__OBJECT_STRING,
 			      G_TYPE_NONE,
-			      2, GOSSIP_TYPE_CONTACT, G_TYPE_STRING);
+			      2, EMPATHY_TYPE_CONTACT, G_TYPE_STRING);
 
 		initialized = TRUE;
 	}
 }
 
 EmpathyContactListInfo *
-empathy_contact_list_info_new (GossipContact *contact,
+empathy_contact_list_info_new (EmpathyContact *contact,
 			       const gchar   *message)
 {
 	EmpathyContactListInfo *info;
 
-	g_return_val_if_fail (GOSSIP_IS_CONTACT (contact), NULL);
+	g_return_val_if_fail (EMPATHY_IS_CONTACT (contact), NULL);
 
 	info = g_slice_new0 (EmpathyContactListInfo);
 	info->contact = g_object_ref (contact);
@@ -124,7 +124,7 @@ empathy_contact_list_setup (EmpathyContactList *list)
 	}
 }
 
-GossipContact *
+EmpathyContact *
 empathy_contact_list_find (EmpathyContactList *list,
 			   const gchar        *id)
 {
@@ -139,7 +139,7 @@ empathy_contact_list_find (EmpathyContactList *list,
 
 void
 empathy_contact_list_add (EmpathyContactList *list,
-			  GossipContact      *contact,
+			  EmpathyContact      *contact,
 			  const gchar        *message)
 {
 	g_return_if_fail (EMPATHY_IS_CONTACT_LIST (list));
@@ -151,7 +151,7 @@ empathy_contact_list_add (EmpathyContactList *list,
 
 void
 empathy_contact_list_remove (EmpathyContactList *list,
-			     GossipContact      *contact,
+			     EmpathyContact      *contact,
 			     const gchar        *message)
 {
 	g_return_if_fail (EMPATHY_IS_CONTACT_LIST (list));
@@ -185,3 +185,17 @@ empathy_contact_list_get_local_pending (EmpathyContactList *list)
 	return NULL;
 }
 
+void
+empathy_contact_list_process_pending (EmpathyContactList *list,
+				      EmpathyContact      *contact,
+				      gboolean            accept)
+{
+	g_return_if_fail (EMPATHY_IS_CONTACT_LIST (list));
+
+	if (EMPATHY_CONTACT_LIST_GET_IFACE (list)->process_pending) {
+		EMPATHY_CONTACT_LIST_GET_IFACE (list)->process_pending (list,
+									contact,
+									accept);
+	}
+}
+
